#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "esp_log.h"
#include "eth.h"
#include "ssd1306.h"
#include "font8x8_basic.h"

// Pure gueses for wESP32 board
#define CONFIG_SDA_GPIO 33
#define CONFIG_SCL_GPIO 5
#define CONFIG_RESET_GPIO -1
#define CONFIG_MODEL 0

#define tag "LCD"

/**
 * @brief Task to manage LCD display
 *
 * FreeRTOS task to manage an OLED I2C display. This implementation currently only supports
 * the SSD1306 chipset.
 *
 */
void lcdFtask(void)
{
	SSD1306_t dev;

	ESP_LOGI(tag, "INTERFACE is i2c");
	ESP_LOGI(tag, "CONFIG_SDA_GPIO=%d", CONFIG_SDA_GPIO);
	ESP_LOGI(tag, "CONFIG_SCL_GPIO=%d", CONFIG_SCL_GPIO);
	ESP_LOGI(tag, "CONFIG_RESET_GPIO=%d", CONFIG_RESET_GPIO);
	i2c_master_init(&dev, CONFIG_SDA_GPIO, CONFIG_SCL_GPIO, CONFIG_RESET_GPIO);

#if CONFIG_FLIP
	dev._flip = true;
	ESP_LOGW(tag, "Flip upside down");
#endif

	ESP_LOGI(tag, "Panel is 128x64");
	ssd1306_init(&dev, 128, 64);

	char *hdr = "LEIGH:plc    mk1";
	ssd1306_clear_screen(&dev, false);
	ssd1306_contrast(&dev, 0xff);
	ssd1306_display_text(&dev, 0, hdr, strlen(hdr), true);

	while (1)
	{
		const char *ip = ethFget_ip_str();
		const char *mac = ethFget_mac_str();
		const char *nm = ethFget_ip_netmask_str();
		const char *gw = ethFget_ip_gateway_str();
		char buf[17];

		snprintf(buf, sizeof(buf), "%-16s", mac);
		ssd1306_display_text(&dev, 2, buf, strlen(buf), false);

		snprintf(buf, sizeof(buf), "%-16s", ip);
		ssd1306_display_text(&dev, 3, buf, strlen(buf), false);

		snprintf(buf, sizeof(buf), "%-16s", nm);
		ssd1306_display_text(&dev, 4, buf, strlen(buf), false);

		snprintf(buf, sizeof(buf), "%-16s", gw);
		ssd1306_display_text(&dev, 5, buf, strlen(buf), false);

		vTaskDelay(3000 / portTICK_PERIOD_MS);
	}
}